@@ -2,19 +2,6 @@ __tool_name__ = 'hackingtools'
 from .core import Connections as __Connections
 from .core import Config, Utils, Logger, Repositories, Objects
 
-# Check Version Update
-import pkg_resources as __pkg
-__version__ = __pkg.get_distribution(__tool_name__).version
-import requests as __req 
-from bs4 import BeautifulSoup as __bs4
-__pypipage__ = __req.get("https://pypi.org/project/hackingtools/")
-if __pypipage__.status_code == 200:
-    __pageContent = __bs4(__pypipage__.content, 'html.parser')
-    __pypiVersion = __pageContent.find('h1', {'class' : 'package-header__name'}).replace(__tool_name__, '').replace(' ', '')
-    if not __version__ == __pypiVersion:
-        Logger.printMessage('Version outdated... Newer version available: {v}'.format(v=__pypiVersion), is_warn=True)
-
-
 __config__ = Config.getConfig(parentKey='core', key='import_modules')
 
 import os as __os
@@ -71,6 +58,23 @@ __workers__ = []
 __telegrambot_name__ = 'ht-bot'
 __telegrambot_token__ = ''
 
+def __checkLibraryUpdate__():
+    try:
+        # Check Version Update
+        import pkg_resources as __pkg
+        __version__ = __pkg.get_distribution(__tool_name__).version
+        import requests as __req 
+        from bs4 import BeautifulSoup as __bs4
+        __pypipage__ = __req.get("https://pypi.org/project/hackingtools/")
+        if __pypipage__.status_code == 200:
+            __pageContent = __bs4(__pypipage__.content, 'html.parser')
+            __pypiHeader = __pageContent.find('h1', {'class' : 'package-header__name'}).text
+            __pypiVersion = __pypiHeader.replace(__tool_name__, '').replace('\n', ' ').replace('\r', '').replace(' ', '')
+            if not __version__ == __pypiVersion:
+                Logger.printMessage('Version outdated... Newer version available: {v}'.format(v=__pypiVersion), is_warn=True)
+    except:
+        pass
+
 def getModulesNames():
     """Return's an Array with all the modules loaded names (ht_shodan, ht_nmap, etc.)
 
@@ -572,6 +576,7 @@ def __importModules__():
                     Logger.printMessage(message='__importModules__', description='{moduleName} File not found: {error}'.format(moduleName=files, error=str(e)), is_error=True)
                     pass
 
+worker('check-library-updated', 'ht.__checkLibraryUpdate__', loop=False, run_until_ht_stops=True, log=__amidjango__)
 worker('refresh-pool-servers', 'ht.Pool.__checkPoolNodes__', timesleep=180, run_until_ht_stops=True, log=__amidjango__)
 worker('clear-htpass-files', 'ht.Config.__cleanHtPassFiles__', timesleep=100, run_until_ht_stops=True, log=__amidjango__)
 worker('clear-uploaded-modules-temp', 'ht.Repositories.clearUploadsTemp', timesleep=200, run_until_ht_stops=True, log=__amidjango__)
